#!/bin/sh
#
#
. ./proc-helper
#
release_ver="1.9+2020-06-06"
release_patch="1.0.9~202006" # check in proc-helper

echo "*****************************************"
echo "*** Script zur Anpassung der Firmware ***"
echo "*** an Erfordernisse von ffhal        ***"
echo "*****************************************"
echo

check=`cat /lib/gluon/release | grep $release_ver`
checkpatch=`cat /lib/gluon/release | grep $release_patch`
if [ "$check" == "" ]
then
  if [ "$checkpatch" == "" ]
  then
   echo "Dieses Patch ist fuer diese Version der Firmware NICHT geeignet!"
   echo
   echo "Bitte eine passende Version herunterladen (falls ueberhaupt ein Patch erforderlich ist) und"
   echo "diese dann ausfuehren ..."
   echo
   exit 1
  fi
  echo "Dieses Patch kann erneut ausgefuehrt werden."
  echo
  echo "Bitte dazu das Kommando update ausfuehren..."
  echo
  exit 2
fi

###########################################
CONF_MODE=`ip a s | grep 'br-setup'`
if [ "$CONF_MODE" == "" ]
then
  echo "Ausfhrung im Config Mode erforderlich..."
  echo
  exit 255
fi

###########################################
echo "-> grille Stuttgarter scripts..."
###########################################
grill_stuttgart
echo

###########################################
echo "-> passe Config-Vorgaben an ffhal an..."
###########################################
ffhal_params_and_files

uci set gluon-setup-mode.@setup_mode[0].configured='1'
echo

###########################################
echo "-> setze Netzwerk-Parameter zu ffhal..."
###########################################
echo -n "."; uci set fastd.sample_config.mtu='1426'
echo -n "."; uci set fastd.mesh_vpn.mtu='1426'
echo -n "."; uci set network.mesh_vpn.mtu='1426'
echo -n "."; uci set network.local_node_dev.macaddr='02:dd:9e:0b:50:1c'
echo -n "."; uci set network.local_node.ipaddr='10.62.0.100/16'
echo -n "."; uci set network.local_node.ip6addr='fd0f:8db3:d50a::100/128'
echo -n "."; uci set network.local_node_route6.target='fd0f:8db3:d50a::/64'
echo -n "."; uci set firewall.mesh_respondd_siteprefix.src_ip='fd0f:8db3:d50a::/64'
##nowdate=`date -u +"%Y %m %d %H %M"`
##set -- `echo $nowdate`
##yr=$1; mn=$2; dy=$3; hr=$4; mi=$5
##echo "8"; uci set system.@system[0].hostname="ffhal-CPE210v3-$yr$mn$dy$hr$mi"
#
#devdata=`ip a s dev eth0`; set -- `echo $devdata`; devdata=`echo $15`; devdata=`echo $devdata | sed  's/://g'`
#devdata=`ip a s dev br-setup`; set -- `echo $devdata`; devdata=`echo $13`; devdata=`echo $devdata | sed  's/://g'`
devdata=`ip a s dev br-setup`; set -- `echo $devdata`; shift 5; devdata=`echo $8`; devdata=`echo $devdata | sed  's/://g'`
###echo "8"; uci set system.@system[0].hostname="ffhal-CPE210v3-adaptiert"
#
# original ffs-3431c46b810e
#
echo "ok";

curr_hostname=`uci get system.@system[0].hostname | grep 'ffs-'`
if [ "$curr_hostname" != "" ]
then
  uci set system.@system[0].hostname="ffhal-$devdata"
fi

echo

#240317x ###########################################
#240317x echo "-> passe weitere Netzwerkeintraege an..."
#240317x ###########################################
#240317x echo -n "."; uci set network.mesh_radio0=interface
#240317x echo -n "."; uci set network.mesh_radio0.proto='gluon_mesh'
#240317x echo -n "."; uci del network.mesh_wan.index
#240317x echo -n "."; uci set network.mesh_wan.auto='0'
#240317x echo -n "."; uci set network.mesh_wan.fixed_mtu='1'
#240317x echo -n "."; uci set network.mesh_wan.proto='gluon_mesh'
#240317x echo -n "."; uci del network.client.ra_holdoff
#240317x echo -n "."; uci del network.gluon_bat0.gw_mode
#240317x echo "ok";   uci set network.mesh_wan.disabled='1'

#240317x uci commit
#240317x echo

#240317x ###########################################
#240317x echo "-> erstelle alfred und richte es ein..."
#240317x ###########################################
#240317x echo -n "touching..."; touch /etc/config/alfred

#240317x echo -n "."; uci set alfred.alfred=alfred
#240317x echo -n "."; uci set alfred.alfred.batmanif='bat0'
#240317x echo -n "."; uci set alfred.alfred.start_vis='1'
#240317x echo -n "."; uci set alfred.alfred.mode='slave'
#240317x echo -n "."; uci set alfred.alfred.run_facters='0'
#240317x echo "ok";   uci set alfred.alfred.interface='br-client'

#240317x uci commit

#240317x ##########################################
#240317x rm -f /etc/rc.d/S99alfred >/dev/null
#240317x rm -f /etc/rc.d/K99alfred >/dev/null
#240317x alfred_files
#240317x echo

#240317x ###########################################
#240317x echo "-> erstelle batman-adv und richte es ein..."
#240317x ###########################################
#240317x echo -n "touching..."; touch /etc/config/batman-adv

#240317x echo -n "."; uci set batman-adv.bat0=mesh
#240317x echo -n "."; uci set batman-adv.bat0.gw_mode='client'
#240317x echo -n "."; uci set batman-adv.bat0.orig_interval='5000'
#240317x echo -n "."; uci set batman-adv.bat0.routing_algo='BATMAN_IV'
#240317x echo -n "."; uci set batman-adv.bat0.hop_penalty='15'
#240317x echo -n "."; uci set batman-adv.bat0.gw_sel_class='1'
#240317x echo "ok";   uci set batman-adv.bat0.multicast_mode='0'

#240317x uci commit

#240317x ##########################################
#240317x batman_files
#240317x echo

##########################################
# bermittlung der Infos an die Seite
# passiert in Halle mit respondd,
# allerdings funktioniert das mit der
# Version aus Stuttgart nicht
##########################################
echo "-> kopiere Dateien von respondd..."
###########################################
respondd_files
echo

###########################################
echo "-> passe Autoupdater-Eintraege an..."
###########################################
echo -n "."; uci del autoupdater.nightly
echo -n "."; uci del autoupdater.beta
echo -n "."; uci del autoupdater.stable.mirror
echo -n "."; uci add_list autoupdater.stable.mirror='http://mirror1.ffhal/stable/images/sysupgrade/'
echo -n "."; uci add_list autoupdater.stable.mirror='http://mirror2.ffhal/stable/images/sysupgrade/'
echo -n "."; uci del autoupdater.stable.pubkey
echo -n "."; uci add_list autoupdater.stable.pubkey='8c52cae214514856aa0502b1684eeebc8f7f95315e618b6743219d93ac0700be'
echo -n "."; uci add_list autoupdater.stable.pubkey='5e8fa01f6f2f963c0d96e07eaf91c29e09b10ffb2100fa5ab8eee92a25ddede9'
echo -n "."; uci set autoupdater.stable.good_signatures='1'
echo -n "."; uci del autoupdater.experimental.mirror
echo -n "."; uci add_list autoupdater.experimental.mirror='http://mirror1.ffhal/experimental/images/sysupgrade/'
echo -n "."; uci add_list autoupdater.experimental.mirror='http://mirror2.ffhal/experimental/images/sysupgrade/'
echo -n "."; uci set autoupdater.experimental.good_signatures='1'
echo -n "."; uci del autoupdater.experimental.pubkey
echo -n "."; uci add_list autoupdater.experimental.pubkey='8c52cae214514856aa0502b1684eeebc8f7f95315e618b6743219d93ac0700be'
echo -n "."; uci add_list autoupdater.experimental.pubkey='5e8fa01f6f2f963c0d96e07eaf91c29e09b10ffb2100fa5ab8eee92a25ddede9'
echo "ok";   uci set autoupdater.settings.enabled='0'

uci commit

############################################
#echo "entferne dnsmasq's nonwildcard..."
############################################
#uci del dhcp.@dnsmasq[0].nonwildcard

##uci commit
echo

#240317x ###########################################
#240317x echo "-> passe dhcp client Eintraege an..."
#240317x ###########################################
#240317x echo -n "."; uci del dhcp.local_client
#240317x echo -n "."; uci set dhcp.client=dhcp
#240317x echo -n "."; uci set dhcp.client.ignore='1'
#240317x echo "ok";   uci set dhcp.client.interface='client'
#240317x echo

###########################################
echo "-> passe VPN Eintraege an..."
###########################################
echo -n ".";  uci del fastd.mesh_vpn.on_connect 2> /dev/null  # ein Auge drauf!!

echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw01
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw02
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw03
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw04
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw05
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw06
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw07
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw08
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw09
echo -n "."; uci del fastd.mesh_vpn_backbone_peer_gw10

echo -n "."; uci set fastd.mesh_vpn_backbone_peer_vpn3=peer
echo -n "."; uci set fastd.mesh_vpn_backbone_peer_vpn3.enabled='1'
echo -n "."; uci set fastd.mesh_vpn_backbone_peer_vpn3.key='c21abf04f9ee3a1906607cf4c8e734addaa8bba8eeb3d405be76248082b0b748'
echo -n "."; uci set fastd.mesh_vpn_backbone_peer_vpn3.net='mesh_vpn'

echo -n "."; uci del fastd.mesh_vpn_backbone_peer_vpn3.remote 2> /dev/null
echo -n "."; uci add_list fastd.mesh_vpn_backbone_peer_vpn3.remote='"vpn3.freifunk-halle.org" port 10000'

echo -n "."; uci set fastd.mesh_vpn_backbone_peer_vpn3.group='mesh_vpn_backbone'

echo -n "."; uci del fastd.mesh_vpn.method
echo -n "."; uci add_list fastd.mesh_vpn.method='null'

echo "ok";   uci set fastd.mesh_vpn.enabled='1'

###########################################
# for debug...                            #
###########################################
# echo "21S"; uci set fastd.mesh_vpn.secret='10c0ac0a49bed094c6b1f1eda54fc73efc3c5ff36834028c4dc2ee8ce5414b47'
##echo "VPN Secret"; uci set fastd.mesh_vpn.secret='f06c8d61b610b607f6ce205a4ee3786c0081e578d11c05632dde9e00370a2078'
##echo "Contact"   ; uci set gluon-node-info.@owner[0].contact='freifunk@faramo.de'
##                   uci set system.@system[0].hostname='y02dev-avmFB7312'
###########################################

uci commit
echo

#240317x ###########################################
#240317x echo "-> passe firewall an..."
#240317x ###########################################
#240317x echo -n "."; uci del firewall.wan_vxlan
#240317x echo -n "."; uci del firewall.wired_mesh_vxlan
#240317x echo -n "."; uci set firewall.@defaults[0].input='ACCEPT'

#240317x echo -n "."; uci del firewall.mesh
#240317x echo -n "."; uci del firewall.mesh_ICMPv6_in
#240317x echo -n "."; uci del firewall.local_client
#240317x echo -n "."; uci del firewall.local_client_ICMPv6_in
#240317x echo -n "."; uci del firewall.wired_mesh
#240317x echo -n "."; uci del firewall.wired_mesh_ICMPv6_in
#240317x echo -n "."; uci del firewall.local_client_ICMPv4_in
#240317x echo -n "."; uci del firewall.local_client_ssh

#240317x echo -n "."; uci set firewall.client=zone
#240317x echo -n "."; uci set firewall.client.name='client'
#240317x echo -n "."; uci set firewall.client.network='client'
#240317x echo -n "."; uci set firewall.client.input='ACCEPT'
#240317x echo -n "."; uci set firewall.client.forward='REJECT'
#240317x echo -n "."; uci set firewall.client.output='ACCEPT'
#240317x echo -n "."; uci set firewall.client_dns=rule
#240317x echo -n "."; uci set firewall.client_dns.dest_port='53'
#240317x echo -n "."; uci set firewall.client_dns.src='client'
#240317x echo -n "."; uci set firewall.client_dns.name='client_dns'
#240317x echo -n "."; uci set firewall.client_dns.target='REJECT'

#240317x echo -n "."; uci set firewall.local_node=zone
#240317x echo -n "."; uci set firewall.local_node.name='local_node'
#240317x echo -n "."; uci set firewall.local_node.input='ACCEPT'
#240317x echo -n "."; uci set firewall.local_node.forward='REJECT'
#240317x echo -n "."; uci set firewall.local_node.network='local_node'
#240317x echo -n "."; uci set firewall.local_node.output='ACCEPT'

#240317x echo -n "."; uci del firewall.mesh_ssh
#240317x echo -n "."; uci del firewall.drop

#240317x echo -n "."; uci del firewall.mesh_respondd_reply
#240317x echo -n "."; uci del firewall.mesh_respondd_ll
#240317x echo -n "."; uci del firewall.mesh_respondd_siteprefix
#240317x echo -n "."; uci set firewall.client_respondd.src='client'
#240317x echo -n "."; uci set firewall.client_respondd.src_ip='!fe80::/64'
#240317x echo -n "."; uci set firewall.client_respondd.target='REJECT'
#240317x echo -n "."; uci del firewall.mesh_http
#240317x echo "ok";   uci del firewall.local_client_http

#240317x uci commit
#240317x echo

###########################################
echo "-> setze Modus als Knoten..."
###########################################
uci set gluon-node-info.@system[0].role='node'

uci commit gluon-node-info
echo

###########################################
echo "-> passe ssid changer an..."
###########################################
# uci set ssid-changer.settings=main
uci set ssid-changer.settings.prefix='Offline_www.freifunk-halle.org_'

##uci commit

###########################################
# uci set uhttpd.defaults.commonname='LEDE'
echo

###########################################
echo "-> passe WLAN Einstellungen an..."
###########################################
# uci del wireless.radio0.legacy_rates

echo -n "."; uci del wireless.radio0.supported_rates 2> /dev/null

echo -n "."; uci add_list wireless.radio0.supported_rates='6000'
echo -n "."; uci add_list wireless.radio0.supported_rates='9000'
echo -n "."; uci add_list wireless.radio0.supported_rates='12000'
echo -n "."; uci add_list wireless.radio0.supported_rates='18000'
echo -n "."; uci add_list wireless.radio0.supported_rates='24000'
echo -n "."; uci add_list wireless.radio0.supported_rates='36000'
echo -n "."; uci add_list wireless.radio0.supported_rates='48000'
echo -n "."; uci add_list wireless.radio0.supported_rates='54000'

echo -n "."; uci del wireless.radio0.basic_rate 2> /dev/null

echo -n "."; uci add_list wireless.radio0.basic_rate='6000'
echo -n "."; uci add_list wireless.radio0.basic_rate='9000'
echo -n "."; uci add_list wireless.radio0.basic_rate='18000'
echo -n "."; uci add_list wireless.radio0.basic_rate='36000'
echo -n "."; uci add_list wireless.radio0.basic_rate='54000'

echo -n "."; uci set wireless.radio0.channel='13'
##echo -n "."; uci set wireless.radio0.country='DE'
echo -n "."; uci set wireless.mesh_radio0.mesh_id='02:CA:FF:EE:BA:BE'
echo "ok";   uci set wireless.client_radio0.ssid='www.freifunk-halle.org'
echo

###########################################
echo "-> passe ntp Einstellungen an..."
###########################################
echo -n "."; uci del system.ntp.server

#echo -n "."; uci add_list system.ntp.server='time1.service.ffhal'
#echo -n "."; uci add_list system.ntp.server='time2.service.ffhal'
echo -n "."; uci add_list system.ntp.server='fd0f:8db3:d50a:0:208:a1ff:fe25:cf0a'
echo -n "."; uci add_list system.ntp.server='131.188.3.220'
echo -n "."; uci add_list system.ntp.server='131.188.3.221'
echo -n "."; uci add_list system.ntp.server='131.188.3.222'
echo -n "."; uci add_list system.ntp.server='192.53.103.108'
echo "ok";

uci commit
echo

###########################################
echo "-> passe LED-Steuerung an..."
###########################################
echo -n "."; uci set system.led_dsl.sysfs='fritz7312:green:power'
echo -n "."; uci set system.led_dsl.mode='link'

echo "ok"

uci commit

cp -f /tmp/store/led-changer.sh  /usr/libexec
chmod 755 /usr/libexec/led-changer.sh
cp -f /tmp/store/led-changer     /usr/lib/micron.d
chmod 644 /usr/lib/micron.d/led-changer

# /etc/init.d/micrond restart   # doesn't run in config mode

echo

###########################################
echo "-> DAC524's Workaround wegen mesh0..."
###########################################
dac524_files

###########################################
echo
echo "Jetzt bitte Config ueber die Browserseite auf http://192.168.1.1"
echo
###########################################
